@@ -103,13 +103,14 @@ bool sinsp_container_manager::resolve_container_from_cgroups(const vector<pair<s
 		//
 		// Non-systemd Docker
 		//
-		pos = cgroup.find("/docker/");
+		pos = cgroup.find_last_of("/");
 		if(pos != string::npos)
 		{
-			if(cgroup.length() - pos - sizeof("/docker/") + 1 == 64)
+			if(cgroup.length() - pos - 1 == 64 &&
+				cgroup.find_first_not_of("0123456789abcdefABCDEF", pos + 1) == string::npos) 
 			{
 				container_info.m_type = CT_DOCKER;
-				container_info.m_id = cgroup.substr(pos + sizeof("/docker/") - 1, 12);
+				container_info.m_id = cgroup.substr(pos + 1, 12);
 				valid_id = true;
 				break;
 			}
@@ -189,6 +190,7 @@ bool sinsp_container_manager::resolve_container_from_cgroups(const vector<pair<s
 			valid_id = true;
 			continue;
 		}
+
 		//
 		// Mesos
 		//
