@@ -40,6 +40,14 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 void *memmem(const void *haystack, size_t haystacklen, const void *needle, size_t needlelen);
 #endif
 
+#ifdef _WIN32
+#pragma comment(lib, "Ws2_32.lib")
+#include <WinSock2.h>
+#else
+#include <netdb.h>
+#endif
+
+
 extern sinsp_filter_check_list g_filterlist;
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -58,6 +66,7 @@ sinsp_filter_check_list::sinsp_filter_check_list()
 	add_filter_check(new sinsp_filter_check_syslog());
 	add_filter_check(new sinsp_filter_check_container());
 	add_filter_check(new sinsp_filter_check_utils());
+	add_filter_check(new sinsp_filter_check_fdlist());
 }
 
 sinsp_filter_check_list::~sinsp_filter_check_list()
@@ -316,6 +325,7 @@ bool flt_compare(ppm_cmp_operator op, ppm_param_type type, void* operand1, void*
 	case PT_SOCKTUPLE:
 	case PT_FDLIST:
 	case PT_FSPATH:
+	case PT_SIGSET:
 	default:
 		ASSERT(false);
 		return false;
@@ -466,7 +476,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_INT16:
@@ -482,7 +492,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_INT32:
@@ -498,7 +508,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_INT64:
@@ -527,7 +537,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_PORT: // This can be resolved in the future
@@ -544,7 +554,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_UINT32:
@@ -560,7 +570,7 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_UINT64:
@@ -580,13 +590,13 @@ Json::Value sinsp_filter_check::rawval_to_json(uint8_t* rawval, const filterchec
 			else
 			{
 				ASSERT(false);
-				return Json::Value::null;
+				return Json::Value::nullRef;
 			}
 
 		case PT_SOCKADDR:
 		case PT_SOCKFAMILY:
 			ASSERT(false);
-			return Json::Value::null;
+			return Json::Value::nullRef;
 
 		case PT_BOOL:
 			return Json::Value((bool)(*(uint32_t*)rawval != 0));
@@ -862,7 +872,29 @@ void sinsp_filter_check::string_to_rawval(const char* str, uint32_t len, ppm_par
 		case PT_UINT8:
 			*(uint8_t*)(&m_val_storage[0]) = sinsp_numparser::parseu8(str);
 			break;
-		case PT_PORT: // This can be resolved in the future
+		case PT_PORT:
+		{
+			string in(str);
+
+			if(in.empty())
+			{
+				*(uint16_t*)(&m_val_storage[0]) = 0;
+			}
+			else
+			{
+				// if the string is made only of numbers
+				if(strspn(in.c_str(), "0123456789") == in.size())
+				{
+					*(uint16_t*)(&m_val_storage[0]) = stoi(in);
+				}
+				else
+				{
+					*(uint16_t*)(&m_val_storage[0]) = ntohs(getservbyname(in.c_str(), NULL)->s_port);
+				}
+			}
+
+			break;
+		}
 		case PT_FLAGS16:
 		case PT_UINT16:
 			*(uint16_t*)(&m_val_storage[0]) = sinsp_numparser::parseu16(str);
@@ -946,12 +978,13 @@ Json::Value sinsp_filter_check::tojson(sinsp_evt* evt)
 	uint32_t len;
 	Json::Value jsonval = extract_as_js(evt, &len);
 
-	if(jsonval == Json::Value::null)
+	if(jsonval == Json::Value::nullRef)
 	{
 		uint8_t* rawval = extract(evt, &len);
 		if(rawval == NULL)
 		{
-			return Json::Value::null;
+			return Json::Value::nullRef
+;
 		}
 		return rawval_to_json(rawval, m_field, len);
 	}
@@ -1293,7 +1326,9 @@ vector<char> sinsp_filter::next_operand(bool expecting_first_operand, bool in_cl
 				escape_state = PES_NUMBER;
 				break;
 			default:
-				escape_state = PES_ERROR;
+				escape_state = PES_NORMAL;
+				res.push_back('\\');
+				res.push_back(curchar);
 				break;
 			}
 			break;
