@@ -85,5 +85,41 @@ view_info =
 			aggregation = "MAX",
 			colsize = 0
 		}
-	}
+	},
+	actions = 
+	{
+		{
+			hotkey = "9",
+			command = "kill -9 %proc.pid",
+			description = "kill -9",
+			wait_finish = false
+		},
+		{
+			hotkey = "c",
+			command = "gcore %proc.pid",
+			description = "generate core",
+		},
+		{
+			hotkey = "g",
+			command = "gdb -p %proc.pid",
+			description = "gdb attach",
+			wait_finish = false
+		},
+		{
+			hotkey = "k",
+			command = "kill %proc.pid",
+			description = "kill",
+			wait_finish = false
+		},
+		{
+			hotkey = "l",
+			command = "ltrace -p %proc.pid",
+			description = "ltrace",
+		},
+		{
+			hotkey = "s",
+			command = "gdb -p %proc.pid --batch --quiet -ex \"thread apply all bt full\" -ex \"quit\"",
+			description = "print stack",
+		},
+	},
 }
