@@ -159,6 +159,10 @@ static void usage()
 "                    epoch, r for relative time from the beginning of the\n"
 "                    capture, d for delta between event enter and exit, and\n"
 "                    D for delta from the previous event.\n"
+" --unbuffered       Turn off output buffering. This causes every single line\n"
+"                    emitted by sysdig to be flushed, which generates higher CPU\n"
+"                    usage but is useful when piping sysdig's output into another\n"
+"                    process or into a script.\n"
 " -v, --verbose      Verbose output.\n"
 "                    This flag will cause the full content of text and binary\n"
 "                    buffers to be printed on screen, instead of being truncated\n"
